@@ -17,8 +17,8 @@ def casing():
     print("--Casing--")
 #Solicitação da inserção de dados
     print ("---Dimensões do invólucro e Fatores de design---")
-    Do= float(input('Insira o diâmetro externo em mm: '))
-    t= float(input('Insira a espessura da parede em mm: '))
+    Do= float(input('Insira o diâmetro externo (mm): '))
+    t= float(input('Insira a espessura da parede (mm): '))
 
 #Opção para escolher a entrada e, consequentemente, a saída
     print(" ")
@@ -66,7 +66,7 @@ def casing():
         print("Pressão de ruptura: Pu= ",'{:.5f}'.format(Pu), " kPa")
         Pd=Pu/Su if Su!=0 else 0
         print("Design de pressão: Pd= ",'{:.5f}'.format(Pd)," kPa")
-        Sd=(2*(t*p['Fty']*1000)/(Do*Pd)) if Do!=0 or Sd!=0 else 0
+        Sd=(2*(t*p['Fty']*1000)/(Do*Pd)) if Do!=0 or Pd!=0 else 0 #corrigir divisão por 0
         print("Fator de design de segurança: Sd= ",'{:.5f}'.format(Sd))
     
     print (" ")
@@ -110,9 +110,11 @@ def casing():
     arquivo.write('\n')
     arquivo.write('Design de pressão: Pd= ')
     arquivo.write('{}'.format(Pd))
+    arquivo.write(' kPa')
     arquivo.write('\n')
     arquivo.write('Pressão de ruptura: Pu= ')
     arquivo.write('{}'.format(Pu))
+    arquivo.write(' kPa')
     arquivo.write('\n')
     if op=="0":
         arquivo.write('Fator de segurança de ruptura: Su= ')
@@ -125,8 +127,10 @@ def casing():
     arquivo.write('Variação no diâmetro do invólucro: dD= ')
     arquivo.write('{}'.format(dD))
     arquivo.write('\n')
+    arquivo.write(' m')
     arquivo.write('Variação na circunferência do invólucro: dc= ')
     arquivo.write('{}'.format(dc))
+    arquivo.write(' m')
     arquivo.write('\n')
     arquivo.write('--------------------------------')
     arquivo.write('\n')
